<template>
	<el-select
		class="w-32"
		:style="{width:selectWidth}"
		v-model="selectValue"
		@change="changeValue"
		:disabled="disabled"
		:placeholder="data.title"
	>
		<el-option v-for="item in data.list" :key="item.value" :value="item.value" :label="item.title"></el-option>
	</el-select>
</template>

<script setup lang="ts">
import { ref, type PropType, computed } from 'vue';
import { getTextWidth } from '/@/utils/util';
import { StepParam } from '../types';

const props = defineProps({
	data: {
		type: Object as PropType<StepParam>,
	},
	disabled: {
		type: Boolean,
		default: false,
	},
});

const emit = defineEmits(['change']);
const SELECT_OFFSET = 47;
const selectWidth = computed(() => {
	if (props.data?.list?.length > 0) {
		// 以最大字长为宽度
		const widthList = props.data.list.map((item) =>
			getTextWidth(item.title, {
				size: fontSize.value,
			})
		);
		const maxWidth = Math.max(...widthList);
		const realWidth = maxWidth + SELECT_OFFSET;
		return realWidth + 'px';
	} else {
		return 0;
	}
});

const fontSize = ref('14px');
const selectValue = defineModel({
	type: String,
});

const changeValue = (val) => {
	emit('change', val);
};
</script>
<style scoped lang="scss">
:deep(.el-input) {
	font-size: v-bind(fontSize);
}
</style>
